==> FreePastry-2.0b2_20070227-source.tgz: pastry-2.0b2_20070227/src/rice/p2p/util/rawserialization/SimpleInputBuffer.java <==
/*******************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate

Copyright 2002-2007, Rice University. Copyright 2006-2007, Max Planck Institute 
for Software Systems.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither the name of Rice  University (RICE), Max Planck Institute for Software 
Systems (MPI-SWS) nor the names of its contributors may be used to endorse or 
promote products derived from this software without specific prior written 
permission.

This software is provided by RICE, MPI-SWS and the contributors on an "as is" 
basis, without any representations or warranties of any kind, express or implied 
including, but not limited to, representations or warranties of 
non-infringement, merchantability or fitness for a particular purpose. In no 
event shall RICE, MPI-SWS or contributors be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages (including, but not 
limited to, procurement of substitute goods or services; loss of use, data, or 
profits; or business interruption) however caused and on any theory of 
liability, whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even if 
advised of the possibility of such damage.

*******************************************************************************/ 
/*
 * Created on Mar 30, 2006
 */
package rice.p2p.util.rawserialization;

import java.io.*;

import rice.p2p.commonapi.rawserialization.InputBuffer;

public class SimpleInputBuffer extends DataInputStream implements InputBuffer {
  ByteArrayInputStream bais;
  
  public SimpleInputBuffer(byte[] bytes) {
    this(bytes,0); 
  }
  public SimpleInputBuffer(byte[] bytes, int skip) {
    super(new ByteArrayInputStream(bytes));
    bais = (ByteArrayInputStream)this.in;
    bais.skip(skip);
  }
  
//  public short peakShort() throws IOException {
//    bais.mark(2);
//    short temp = readShort();
//    bais.reset();
//    return temp;
//  }
  
  public int bytesRemaining() {
    try {
      return this.available();
    } catch (IOException ioe) {
      ioe.printStackTrace();
    }
    return -1;
  }  
}

==> FreePastry-2.1b_20081028-source.tgz: pastry-2.1b_20081028/src/rice/p2p/util/rawserialization/SimpleInputBuffer.java <==
/*******************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate

Copyright 2002-2007, Rice University. Copyright 2006-2007, Max Planck Institute 
for Software Systems.  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither the name of Rice  University (RICE), Max Planck Institute for Software 
Systems (MPI-SWS) nor the names of its contributors may be used to endorse or 
promote products derived from this software without specific prior written 
permission.

This software is provided by RICE, MPI-SWS and the contributors on an "as is" 
basis, without any representations or warranties of any kind, express or implied 
including, but not limited to, representations or warranties of 
non-infringement, merchantability or fitness for a particular purpose. In no 
event shall RICE, MPI-SWS or contributors be liable for any direct, indirect, 
incidental, special, exemplary, or consequential damages (including, but not 
limited to, procurement of substitute goods or services; loss of use, data, or 
profits; or business interruption) however caused and on any theory of 
liability, whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even if 
advised of the possibility of such damage.

*******************************************************************************/ 
/*
 * Created on Mar 30, 2006
 */
package rice.p2p.util.rawserialization;

import java.io.*;
import java.nio.ByteBuffer;

import rice.p2p.commonapi.rawserialization.InputBuffer;

public class SimpleInputBuffer extends DataInputStream implements InputBuffer {
  ByteArrayInputStream bais;
  
  public SimpleInputBuffer(ByteBuffer bb) {
    this(bb.array(),bb.position(),bb.remaining()); 
  }
  public SimpleInputBuffer(byte[] bytes) {
    this(bytes,0,bytes.length); 
  }
  public SimpleInputBuffer(byte[] bytes, int offset) {
    this(bytes,offset,bytes.length-offset); 
  }
  public SimpleInputBuffer(byte[] bytes, int offset, int length) {
    super(new ByteArrayInputStream(bytes, offset, length));
    bais = (ByteArrayInputStream)this.in;
  }
  
//  public short peakShort() throws IOException {
//    bais.mark(2);
//    short temp = readShort();
//    bais.reset();
//    return temp;
//  }
  
  public int bytesRemaining() {
    try {
      return this.available();
    } catch (IOException ioe) {
      ioe.printStackTrace();
    }
    return -1;
  }  
}
